.. PyQt-Fit documentation master file, created by
   sphinx-quickstart on Sat Jan  5 18:12:21 2013.

Welcome to PyQt-Fit's documentation!
====================================

PyQt-Fit is a regression toolbox in Python with simple GUI and graphical tools
to check your results. It currently handles regression based on user-defined
functions with user-defined residuals (i.e. parametric regression) or
non-parametric regression, either local-constant or local-linear, with the
option to provide your own. The GUI currently provides an interface only to
parametric regression.

Contents:

.. toctree::
  :maxdepth: 2

  intro
  GUI_tut
  Param_tut
  NonParam_tut
  KDE_tut
  modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

